1.0.0 - 21 February 2020
==========================

Initial Release

1.1.0 - 21 Februrary 2020
===========================

Fixes import errors, Discord connections not showing and accounts for API changes
